# Herzlich Willkommen

Das hier ist das Repository, in dem der Lehrstuhl Digital Social Science
nützliche und hilfreiche Funktionen für die Erstellung, Bearbeitung und
Visualisierung von Netzwerken sammelt. Das ganze Package heißt
`dsslab-net-bench` und fußt auf den populären Packages
[NetworkX](https://networkx.org/) und [Matplotlib](https://matplotlib.org/).
Dabei erweitert es diese um für uns sinnvolle und dogmatische Abstraktionen.

## [Dokumentation](https://dsslab.wiso.uni-hamburg.de/net-bench/latest/)

## [Entwicklung](https://gitlab.rrz.uni-hamburg.de/DSS/dev/dsslab-net-bench/-/blob/main/CONTRIBUTING.md)

## Lizenz

GNU General Public License v3.0 or later

Siehe [LICENSE](LICENSE) für den gesamten Text.
